==> haskell-kvitable-1.1.1.0-3-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.1.1.0
visibility:           public
id:                   kvitable-1.1.1.0-CvbNvV7AqzCHyicAPIUAox
key:                  kvitable-1.1.1.0-CvbNvV7AqzCHyicAPIUAox
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  f526d068c5572de11da2070e3ee35ae8
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Internal.Helpers Data.KVITable.Render
    Data.KVITable.Render.ASCII Data.KVITable.Render.HTML
    Data.KVITable.Render.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kvitable-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kvitable-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kvitable-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.1.1.0-CvbNvV7AqzCHyicAPIUAox
depends:
    base-4.18.2.1 containers-0.6.7
    lucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    named-text-1.2.2.0-FWRZ6JMUbbECbmbyhIGjSQ
    sayable-1.2.6.0-Fuydsx71HXZJrlJ9X45bN1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kvitable-1.1.1.0-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.1.1.0
visibility:           public
id:                   kvitable-1.1.1.0-8JvYnGLkLM01CcyWRVV4li
key:                  kvitable-1.1.1.0-8JvYnGLkLM01CcyWRVV4li
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  c7d4f323a17365945be66913b9701e69
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Internal.Helpers Data.KVITable.Render
    Data.KVITable.Render.ASCII Data.KVITable.Render.HTML
    Data.KVITable.Render.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kvitable-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kvitable-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kvitable-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.1.1.0-8JvYnGLkLM01CcyWRVV4li
depends:
    base-4.18.2.1 containers-0.6.7
    lucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    named-text-1.2.2.0-1BqVCoIq2r7HmOULOCRYSv
    sayable-1.2.6.0-Fuydsx71HXZJrlJ9X45bN1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
